@@ -48,7 +48,7 @@ lsm_l_ta.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_ta_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -64,7 +64,7 @@ lsm_l_ta.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_ta_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -80,7 +80,7 @@ lsm_l_ta.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_ta_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -98,7 +98,7 @@ lsm_l_ta.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_ta_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -114,7 +114,7 @@ lsm_l_ta.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_ta_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
