@@ -55,7 +55,7 @@ lsm_p_area.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_p_area_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -71,7 +71,7 @@ lsm_p_area.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_p_area_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                   vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -87,7 +87,7 @@ lsm_p_area.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_p_area_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -105,7 +105,7 @@ lsm_p_area.stars <- function(landscape, directions = 8) {
                      FUN = lsm_p_area_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -121,7 +121,7 @@ lsm_p_area.list <- function(landscape, directions = 8) {
                      FUN = lsm_p_area_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
